/** @type {import('tailwindcss').Config} */

const defaultTheme = require('tailwindcss/defaultTheme')
const Color = require('color')
const alpha = (clr, val) => Color(clr).alpha(val).rgb().string()
const lighten = (clr, val) => Color(clr).lighten(val).rgb().string()
const darken = (clr, val) => Color(clr).darken(val).rgb().string()

module.exports = {
	darkMode: 'class',
	content: ['./src/**/*.{html,ts}'],
	theme: {
		colors: {
			light: {
				c1: '#FFFFFF',
				c2: '#F6F7FA',
				c3: '#443F51',
				c4: '#6D7386',
				c4_10: alpha('#6D7386', 0.1),
				c5: '#2F2C3A',
				c6: '#FFB200',
				hover: {
					c6: lighten('#FFB200', 0.2)
				}
			},

			dark: {
				c1: '#2F2C3A',
				c2: '#373343',
				c3: '#443F51',
				c4: '#B0B4BC',
				c4_10: alpha('#B0B4BC', 0.1),
				c5: '#FFFFFF',
				c6: '#FFB200',
				hover: {
					c6: darken('#FFB200', 0.2)
				}
			},

			forms: {
				light: {
					background: '#FCFCFC'
				},
				dark: {
					background: '#272332'
				}
			},

			alerts: {
				danger: {
					text: '#C70F0F',
					background: '#FFCACA'
				},
				success: {
					text: '#407B24',
					background: '#CBEABC'
				},
				warning: {
					text: '#C78F0F',
					background: '#FFEFCA'
				},
				info: {
					text: '#3B73DE',
					background: '#E6F1FA'
				},
				hover: {
					success: darken('#CBEABC', 0.1),
					danger: darken('#FFCACA', 0.1),
					warning: darken('#FFEFCA', 0.1),
					info: darken('#E6F1FA', 0.1),
					primary: darken('#FFB200', 0.1)
				}
			}
		},
		fontFamily: {
			sans: ['Inter', ...defaultTheme.fontFamily.sans]
		},
		fontSize: {
			max: [
				'84px',
				{
					letterSpacing: '-0.01em',
					lineHeight: '94px'
				}
			],
			'5xl': [
				'64px',
				{
					letterSpacing: '-0.01em',
					lineHeight: '94px'
				}
			],
			'4xl': [
				'38px',
				{
					letterSpacing: '-0.01em',
					lineHeight: '44px'
				}
			],
			'3xl': [
				'32px',
				{
					letterSpacing: '-0.01em',
					lineHeight: '44px'
				}
			],
			'2xl': [
				'28px',
				{
					letterSpacing: '-0.01em',
					lineHeight: '34px'
				}
			],
			'1xl': [
				'20px',
				{
					letterSpacing: '-0.01em',
					lineHeight: '34px'
				}
			],
			xl: [
				'18px',
				{
					letterSpacing: '-0.01em',
					lineHeight: '34px'
				}
			],
			lg: [
				'16px',
				{
					letterSpacing: '-0.01em',
					lineHeight: '26px'
				}
			],
			md: [
				'14px',
				{
					letterSpacing: '-0.01em',
					lineHeight: '24px'
				}
			],
			sm: [
				'12px',
				{
					letterSpacing: '-0.01em',
					lineHeight: '18px'
				}
			]
		},
		backgroundSize: {
			default_size: '0%, 100%',
			focus_size: '100%, 100%'
		},
		backgroundImage: {
			field_focus:
				'linear-gradient(to top, #FFB200, #FFB200 2px, transparent 2px, transparent 100%)'
		},
		transitionProperty: {
			field_props: 'background-image, background-size, background-color'
		}
	},
	plugins: []
}
